<?php
/*
 * This file is part of EC-CUBE
 *
 * Copyright(c) 2000-2015 LOCKON CO.,LTD. All Rights Reserved.
 *
 * http://www.lockon.co.jp/
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */


namespace Eccube\Form\Type\Admin;

use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolverInterface;
use Symfony\Component\Validator\Constraints as Assert;

class CategoryType extends AbstractType
{
    private $config;

    public function __construct($config)
    {
        $this->config = $config;
    }

    /**
     * {@inheritdoc}
     */
    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $builder
            ->add('name', 'text', array(
                'label' => 'カテゴリ名',
                'constraints' => array(
                    new Assert\NotBlank(),
                    new Assert\Length(array(
                        'max' => $this->config['stext_len'],
                    )),
                ),
            ))
            ->add('category_description', 'textarea', array(
                'label' => 'カテゴリー説明',
                'required' => false,
            ))
			// ▼SEO title・metaタグ
            ->add('seo_title', 'text', array(
                'label' => 'title',
                'required' => false,
            ))
            ->add('seo_author', 'text', array(
                'label' => 'author',
                'required' => false,
            ))
            ->add('seo_description', 'text', array(
                'label' => 'description',
                'required' => false,
            ))
            ->add('seo_keyword', 'text', array(
                'label' => 'keyword',
                'required' => false,
            ))
            ->add('seo_meta_robots', 'text', array(
                'label' => 'meta_robots',
                'required' => false,
            ))
			// ▼カテゴリ画像
            ->add('page_image_file', 'file', array(
                'label' => '画像',
                'mapped' => false,
                'required' => false,
            ))
            ->add('page_image', 'hidden', array(
                'required' => false,
            ))
        ;
    }

    /**
     * {@inheritdoc}
     */
    public function setDefaultOptions(OptionsResolverInterface $resolver)
    {
        $resolver->setDefaults(array(
            'data_class' => 'Eccube\Entity\Category',
        ));
    }

    /**
     * {@inheritdoc}
     */
    public function getName()
    {
        return 'admin_category';
    }
}
